@@ -40,9 +40,9 @@ Unordered lists
 
 Definition lists 
 
-    =for item :term<XML>
+    =defn XML
     Extensible Markup Language
-    =for item :term<HTML>
+    =defn HTML
     Hyper Text Markup Language
 
 
@@ -235,7 +235,7 @@ DOCUMENTING !DOCUMENTING !DOCUMENTING !DOCUMENTING !DOCUMENTING !
 
 =cut
 
-$Perl6::Pod::VERSION = '0.24';
+$Perl6::Pod::VERSION = '0.27';
 
 use warnings;
 use strict;
