@@ -3,6 +3,7 @@ use warnings;
 use strict;
 use Perl6::Pod::Directive::use;
 use Perl6::Pod::Directive::config;
+use Perl6::Pod::Directive::alias;
 use Perl6::Pod::Block::comment;
 use Perl6::Pod::Block::code;
 use Perl6::Pod::Block::pod;
@@ -10,13 +11,25 @@ use Perl6::Pod::Block::para;
 use Perl6::Pod::Block::table;
 use Perl6::Pod::Block::output;
 use Perl6::Pod::Block::input;
+use Perl6::Pod::Block::nested;
+use Perl6::Pod::Block::item;
+use Perl6::Pod::Parser::NOTES;
+use Perl6::Pod::FormattingCode::A;
 use Perl6::Pod::FormattingCode::C;
+use Perl6::Pod::FormattingCode::D;
+use Perl6::Pod::FormattingCode::K;
 use Perl6::Pod::FormattingCode::M;
 use Perl6::Pod::FormattingCode::L;
 use Perl6::Pod::FormattingCode::P;
 use Perl6::Pod::FormattingCode::B;
 use Perl6::Pod::FormattingCode::I;
+use Perl6::Pod::FormattingCode::S;
+use Perl6::Pod::FormattingCode::U;
 use Perl6::Pod::FormattingCode::X;
+use Perl6::Pod::FormattingCode::E;
+use Perl6::Pod::FormattingCode::T;
+use Perl6::Pod::FormattingCode::N;
+use Perl6::Pod::FormattingCode::Z;
 
 use Tie::UnionHash;
 use Data::Dumper;
@@ -36,19 +49,37 @@ use constant {
         use     => 'Perl6::Pod::Directive::use',
         config  => 'Perl6::Pod::Directive::config',
         comment => 'Perl6::Pod::Block::comment',
+        alias   => 'Perl6::Pod::Directive::alias',
         code    => 'Perl6::Pod::Block::code',
         pod     => 'Perl6::Pod::Block::pod',
         para    => 'Perl6::Pod::Block::para',
         table   => 'Perl6::Pod::Block::table',
         output  => 'Perl6::Pod::Block::output',
         input   => 'Perl6::Pod::Block::input',
+        nested  => 'Perl6::Pod::Block::nested',
+        item    => 'Perl6::Pod::Block::item',
+        defn    => 'Perl6::Pod::Block::item',
+        '_NOTES_'   => 'Perl6::Pod::Parser::NOTES',
         'C<>'   => 'Perl6::Pod::FormattingCode::C',
+        'D<>'   => 'Perl6::Pod::FormattingCode::D',
+        'K<>'   => 'Perl6::Pod::FormattingCode::K',
         'M<>'   => 'Perl6::Pod::FormattingCode::M',
         'L<>'   => 'Perl6::Pod::FormattingCode::L',
         'B<>'   => 'Perl6::Pod::FormattingCode::B',
         'I<>'   => 'Perl6::Pod::FormattingCode::I',
         'X<>'   => 'Perl6::Pod::FormattingCode::X',
-#        'P<>'   => 'Perl6::Pod::FormattingCode::P',
+
+        #        'P<>'   => 'Perl6::Pod::FormattingCode::P',
+        'U<>' => 'Perl6::Pod::FormattingCode::U',
+        'E<>' => 'Perl6::Pod::FormattingCode::E',
+        'N<>' => 'Perl6::Pod::FormattingCode::N',
+        'A<>' => 'Perl6::Pod::FormattingCode::A',
+        'R<>' => 'Perl6::Pod::FormattingCode::R',
+        'S<>' => 'Perl6::Pod::FormattingCode::S',
+        'T<>' => 'Perl6::Pod::FormattingCode::T',
+        'V<>' => 'Perl6::Pod::FormattingCode::C', #V like C
+        'Z<>' => 'Perl6::Pod::FormattingCode::Z',
+
     }
 };
 
@@ -62,12 +93,14 @@ sub new {
 
     #set default contexts
     my %args = (
-        _usef     => {},
-        _use      => DEFAULT_USE,
-        _config   => {},
-        _encoding => 'UTF-8',
-        _custom   => {},
-        _class_opts=>{},
+        _usef       => {},
+        _alias       => {},
+        _use        => DEFAULT_USE,
+        _config     => {},
+        _encoding   => 'UTF-8',
+        _custom     => {},
+        _class_opts => {},
+        _allow_context => {},
         @_
     );
 
@@ -141,7 +174,7 @@ return ref to hash of Class optioons to create loaded by use mods
 =cut
 
 sub class_opts {
-    return $_[0]->{_class_opts}
+    return $_[0]->{_class_opts};
 }
 
 =head2 set_use <module_name>, ':config_options'
